@@ -118,7 +118,8 @@ def select_headers(headers, include_headers):
         lastindex[h] = i
     return sign_headers
 
-FWS = r'(?:\r?\n\s+)?'
+# FWS  =  ([*WSP CRLF] 1*WSP) /  obs-FWS ; Folding white space  [RFC5322]
+FWS = r'(?:(?:\s*\r?\n)?\s+)?'
 RE_BTAG = re.compile(r'([;\s]b'+FWS+r'=)(?:'+FWS+r'[a-zA-Z0-9+/=])*(?:\r?\n\Z)?')
 
 def hash_headers(hasher, canonicalize_headers, headers, include_headers,
@@ -540,7 +541,7 @@ class DKIM(object):
         raise KeyFormatError("missing public key: %s"%name)
     try:
         pub = parse_tag_value(s)
-    except InvalidTagValueList:
+    except InvalidTagValueList as e:
         raise KeyFormatError(e)
     try:
         pk = parse_public_key(base64.b64decode(pub[b'p']))
@@ -589,7 +590,7 @@ def sign(message, selector, domain, privkey, identity=None,
 
     d = DKIM(message,logger=logger)
     if not include_headers:
-        include_headers = d.all_sign_headers()
+        include_headers = d.default_sign_headers()
     return d.sign(selector, domain, privkey, identity=identity, canonicalize=canonicalize, include_headers=include_headers, length=length)
 
 def verify(message, logger=None, dnsfunc=get_txt, minkey=1024):
